ruptures: change point detection in Python
====================================================================================================

Short description
----------------------------------------------------------------------------------------------------

__ruptures__ is a Python library for offline change point detection. This package provides methods for the analysis and segmentation of non-stationary signals. Implemented algorithms include exact and approximate detection for various parametric and non-parametric models. __ruptures__ focuses on ease of use by providing a well-documented and consistent interface. In addition, thanks to its modular structure, different algorithms and models can be connected and extended within this package.


An extensive documentation is available `here <ctruong.perso.math.cnrs.fr/ruptures>`_